function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/*
    Author: andrew
    Date: 2019/06/17
    Usage: FeeStyledForm
*/
// react
import * as React from 'react'; // shared component

import { StyledGrid, StyledGridBorder, StyledTitleGridBorder } from "./StyledGrid";
import { Title } from "./Title";
import FormAlertBlock from "../alert/FormAlertBlock"; // material component

import { withStyles } from '@material-ui/core/styles';

const cellStyles = () => ({
  high_100: {
    height: '100%'
  },
  width_100: {
    width: '100%'
  },
  from_title: {
    width: '100px'
  },
  from_value: {
    width: 'calc(100% - 100px)'
  },
  bgColorYellow: {
    backgroundColor: '#ffff02'
  },
  bgColorBlue: {
    backgroundColor: '#02ffff'
  },
  input_title: {
    paddingTop: '10px',
    paddingBottom: '5px',
    paddingRight: '3px'
  },
  input_value: {
    padding: '6px 5px'
  }
});

const formStyles = () => ({
  paddingBottom: {
    paddingBottom: '24px'
  }
});

class FormCell extends React.Component {
  constructor(...args) {
    super(...args);

    this.getCellTitleBgColor = () => {
      const {
        cellStatus
      } = this.props;
      const cellTitleBgColorMap = {
        view: undefined,
        required: '#ffff02',
        edit: '#02ffff'
      };
      return cellTitleBgColorMap[cellStatus] || '';
    };

    this.getCellValueBgColor = () => this.props.cellValueBgColor;

    this.renderWarnMsg = warnMessage => {
      return warnMessage && React.createElement("div", {
        style: {
          color: '#fdb900'
        }
      }, warnMessage);
    };

    this.renderErrMsg = errMessage => {
      return errMessage && React.createElement("div", {
        style: {
          color: 'red'
        }
      }, errMessage);
    };

    this.renderNoTitleCell = () => {
      const {
        classes,
        errMessage,
        warnMessage,
        showCellErrMsg
      } = this.props;
      return React.createElement(StyledGrid, _extends({
        item: true
      }, this.props.widthWeight, {
        className: classes.width_100
      }), React.createElement(StyledGrid, {
        container: true,
        className: classes.high_100
      }, React.createElement(StyledGridBorder, {
        item: true,
        xs: 12,
        style: {
          backgroundColor: this.getCellValueBgColor()
        }
      }, this.props.children, showCellErrMsg && (this.renderErrMsg(errMessage) || this.renderWarnMsg(warnMessage)))));
    };

    this.renderHasTitleCell = () => {
      const {
        classes,
        errMessage,
        validateMessage,
        warnMessage,
        showCellErrMsg
      } = this.props; // 參考資料 : https://stackoverflow.com/questions/46066675/how-to-add-multiple-classes-in-material-ui-using-the-classes-props
      //   className={`${this.props.classes.from_title} ${this.getCellTitleBgColor()}`}

      return React.createElement(StyledGrid, _extends({
        item: true
      }, this.props.widthWeight, {
        className: classes.width_100
      }), React.createElement(StyledGrid, {
        container: true,
        className: classes.high_100
      }, React.createElement(StyledTitleGridBorder, {
        item: true,
        className: this.props.classes.from_title,
        style: {
          backgroundColor: this.getCellTitleBgColor()
        }
      }, React.createElement("div", {
        className: this.props.classes.input_title
      }, this.props.title)), React.createElement(StyledGridBorder, {
        item: true,
        className: classes.from_value,
        style: {
          backgroundColor: this.getCellValueBgColor()
        }
      }, React.createElement("div", {
        className: this.props.classes.input_value
      }, this.props.children, showCellErrMsg && (this.renderErrMsg(errMessage) || this.renderWarnMsg(warnMessage))))));
    };
  }

  render() {
    return this.props.title ? this.renderHasTitleCell() : this.renderNoTitleCell();
  }

}

FormCell.defaultProps = {
  showCellErrMsg: false,
  widthWeight: {
    xs: 12,
    sm: 6,
    md: 2,
    lg: undefined
  }
};
const StyledFormCell = withStyles(cellStyles)(FormCell);

const FormRow = props => React.createElement(StyledGrid, {
  container: true
}, props.children);

const FeeForm = props => React.createElement("form", {
  ref: props.onRef
}, props.title && React.createElement(Title, {
  title: props.title
}), React.createElement(FormAlertBlock, {
  alertOpen: props.alertOpen,
  alertMessage: props.alertMessage,
  fieldMapper: props.fieldMapper
}), React.createElement("div", {
  className: props.classes.paddingBottom
}, props.children));

const FeeStyledForm = withStyles(formStyles)(FeeForm);
export { StyledFormCell, FormRow, FeeStyledForm };